#!/bin/zsh

CURRENT=$(git branch | grep \* | cut -d ' ' -f2)
if [ "$CURRENT" != "main" ]; then
  echo "Not on main branch"
  exit 1
fi

### Running build script
if [ -z "$1" ]; then
  echo "Usage: $0 <version> e.g. 0.8.0-beta.1"
  exit 1
fi

FILE_VERSION=$("$1" | sed -r 's|^(([0-9]+).([0-9]+).([0-9]+))(.*)$|\1|')

sed -i "" -e "s|<AssemblyVersion>.*</AssemblyVersion>|<AssemblyVersion>$FILE_VERSION</AssemblyVersion>|" FitConnect/FitConnect.csproj
sed -i "" -e "s|<FileVersion>.*</FileVersion>|<FileVersion>$FILE_VERSION</FileVersion>|" FitConnect/FitConnect.csproj
sed -i "" -e "s|<PackageVersion>.*</PackageVersion>|<PackageVersion>$1</PackageVersion>|" FitConnect/FitConnect.csproj
sed -i "" -e "s|public const string PackageVersion = \".*\";|public const string PackageVersion = \"$1\";|" FitConnect/ProjectSpecification.cs


COMMIT_ID=$(git rev-parse --short HEAD)

sed -i "" -e "s|public const string CommitId.*|public const string CommitId = \"$COMMIT_ID\";|" FitConnect/ProjectSpecification.cs

dotnet clean

if ! dotnet build FitConnect -c Release; then
  echo "Build failed"
  exit 1
fi

if ! dotnet pack -c Release; then
  echo "Pack failed"
  exit 1
fi

cp "FitConnect/bin/Release/FitConnect.$1.nupkg" .


git add . && git commit -m "Version $1" && git tag -a "$1" -m "Version $1" && git push && git push --tags
dotnet nuget push "FitConnect.$1.nupkg" -k $(cat nuget_api.txt) -s https://api.nuget.org/v3/index.json

